@@ -22,6 +22,12 @@ class MujocoViewer:
         self._paused = False
         self._transparent = False
         self._contacts = False
+        self._joints = False
+        self._shadows = True
+        self._wire_frame = False
+        self._convex_hull_rendering = False
+        self._inertias = False
+        self._com = False
         self._render_every_frame = True
         self._image_idx = 0
         self._image_path = "/tmp/frame_%07d.png"
@@ -109,6 +115,9 @@ class MujocoViewer:
             self._contacts = not self._contacts
             self.vopt.flags[mujoco.mjtVisFlag.mjVIS_CONTACTPOINT] = self._contacts
             self.vopt.flags[mujoco.mjtVisFlag.mjVIS_CONTACTFORCE] = self._contacts
+        elif key == glfw.KEY_J:
+            self._joints = not self._joints
+            self.vopt.flags[mujoco.mjtVisFlag.mjVIS_JOINT] = self._joints
         # Display coordinate frames
         elif key == glfw.KEY_E:
             self.vopt.frame = 1 - self.vopt.frame
@@ -122,6 +131,28 @@ class MujocoViewer:
                 self.model.geom_rgba[:, 3] /= 5.0
             else:
                 self.model.geom_rgba[:, 3] *= 5.0
+        # Display inertia
+        elif key == glfw.KEY_I:
+            self._inertias = not self._inertias
+            self.vopt.flags[mujoco.mjtVisFlag.mjVIS_INERTIA] = self._inertias
+        # Display center of mass
+        elif key == glfw.KEY_M:
+            self._com = not self._com
+            self.vopt.flags[mujoco.mjtVisFlag.mjVIS_COM] = self._com
+        # Shadow Rendering
+        elif key == glfw.KEY_O:
+            self._shadows = not self._shadows
+            self.scn.flags[mujoco.mjtRndFlag.mjRND_SHADOW] = self._shadows
+        # Convex-Hull rendering
+        elif key == glfw.KEY_V:
+            self._convex_hull_rendering = not self._convex_hull_rendering
+            self.vopt.flags[
+                mujoco.mjtVisFlag.mjVIS_CONVEXHULL
+            ] = self._convex_hull_rendering
+        # Wireframe Rendering
+        elif key == glfw.KEY_W:
+            self._wire_frame = not self._wire_frame
+            self.scn.flags[mujoco.mjtRndFlag.mjRND_WIREFRAME] = self._wire_frame
         # Geom group visibility
         elif key in (glfw.KEY_0, glfw.KEY_1, glfw.KEY_2, glfw.KEY_3, glfw.KEY_4):
             self.vopt.geomgroup[key - glfw.KEY_0] ^= 1
@@ -369,10 +400,34 @@ class MujocoViewer:
             topleft,
             "[C]ontact forces",
             "On" if self._contacts else "Off")
+        add_overlay(
+            topleft,
+            "[J]oints",
+            "On" if self._joints else "Off")
+        add_overlay(
+            topleft,
+            "[I]nertia",
+            "On" if self._inertias else "Off")
+        add_overlay(
+            topleft,
+            "Center of [M]ass",
+            "On" if self._com else "Off")
+        add_overlay(
+            topleft, "Shad[O]ws", "On" if self._shadows else "Off"
+        )
         add_overlay(
             topleft,
             "T[r]ansparent",
             "On" if self._transparent else "Off")
+        add_overlay(
+            topleft,
+            "[W]ireframe",
+            "On" if self._wire_frame else "Off")
+        add_overlay(
+            topleft,
+            "Con[V]ex Hull Rendering",
+            "On" if self._convex_hull_rendering else "Off",
+        )
         if self._paused is not None:
             if not self._paused:
                 add_overlay(topleft, "Stop", "[Space]")
@@ -481,4 +536,4 @@ class MujocoViewer:
 
     def close(self):
         glfw.terminate()
-        sys.exit(0)
+        self.ctx.free()
